componenttools.sum_duration_of_components_in_seconds
====================================================

.. autofunction:: abjad.tools.componenttools.sum_duration_of_components_in_seconds.sum_duration_of_components_in_seconds
